bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 10. Aventiure
___________________________________________________ #### <Wie Prvnhilt ze Wormz enphangen wart>
| ### nderthalp des Rins sach man mit manigen scharn ### den kvnich mit sinen gesten zuo dem stade varn ### man sach ovch da bi <zovme> leiten manich meit ### die si ephahen solden die waren alle bereit
###### 539 | ### Do die von Islande zen schifen komen dan ### vnd ovch von Niblvnge Sifrides man ### si gahten zuo dem lande vnmuozech wart ir hant ### da man des kvniges frivnde anderthalp des stades vant
###### 540 | ### Nv hort ovch disiv mere von der kunigin ### voten der vil richen wie si diu meidin ### gefrvmte von der burge dar si da selbe reit ### da gewan an ander kvnde vil manich riter vn– meit
###### 541 | ### Vil manigen buhurt richen sach man dan getriben ### von helden lobelichen niht wol <wær> ez beliben ### vor Chriemhilde der schoenen zuo dem schifen dan ### do huop man von den moern manige vrowen wolgetan
###### 542 | ### Der kvnich was komen vber vnd manich werder gast ### hei waz starker schefte vor den frowen <brast> ### man horte da hurtlichen von schilden manigen stoz ### hei waz riker bukeln vor gedrange lûte erdoz
###### 543 | ### Die vil minneclichen stvonden an der habe ### Gvnther mit sinen gesten gie von schifen <habe> ### er fuorte Pruonhilde selbe an siner hant ### da luhte wider an ander vil <liehte> steine vn– gewant
###### 544 | ### Mit vil grozen zvhten vro Kriemhilt do gie ### da si vron Pruonhilde vnd ir gesinde enphie ### man sach da schappel ruken mit wizen henden dan ### da si sich kvsten beide daz wart durch liebe getan
###### 545 | ### Do sprach gezogenlichen Kriemhilt daz meidin ### ir svlt zue disen landen vns willechomen sin ### mir vnd miner muoter vnd allen die wir han ### der getriwen vrivnden do wart da nigen getan
###### 546 | ### Die frowen sich beviengen mit armen diche hie ### so minneclich enphahen gehorte man noch nie ### so die vrowen beide der bruote taten kvnt ### frov vote vnd ir tohter si chusten diche ir suezen mvnt
###### 547 | ### Do Pruonhilde frowen vol komen vf den sant ### da wart minneclichen genomen bi der hant ### von wetlichen rechen manic wip wolgetan ### man sach die edelen meide vor vron Prvnhilde stan
###### 548 | ### E daz ir grvoz ergienge daz was ein lengiv stvnt [23a] ### ia wart da gechusset manich roter mvnt ### noch stuonden bi an ander die kvnige tohtre rich ### daz liebe an ze sehene manigen reken lobelich
###### 549 | ### Do spehten mit den ovgen die ê horten iehen ### daz si also schoenes heten niht gesehen ### so die frowen beide des iach man an luge ### man kos an ir libe deheiner slahte trvge
###### 550 | ### Die <vrowen> spehen chvnden vnd minneclichen lip ### die lobten durch ir schoene daz Gvnthers wip ### do sprachen da die wisen die hetenz baz besehen ### man mohte Kriemhilde fur Prvnhilde iehen
###### 551 | ### Vider an ander giengen maget vnde wip ### man sach da wol geciert vil manigen schonen lip ### da stuonden sidin hutten vnd manich guot gezelt ### der was da gar erfullet vor Wormez allez daz velt
###### 552 | ### Nv waren ovch die geste ce rossen alle komen ### vil mnanich rich tiost dvrch schilde wart genomen ### daz velt begvnde stovben sam ob al daz lant ### mit <lavge> were enbrunnen da wurden helde wol bechant
###### 553 | ### Des da di reken phlagen daz sach vil manich meit ### mich dvnket daz er Sifrit mit sinen degen reit ### vil manige widerkere fur die hvtten dan ### er fuorte der Niblvnge tvsent wætlicher man
###### 554 | ### Do kom von Trony Hagne als im der wirt geriet ### den buhurt minnechlichen do der helt geschiet ### daz vngestovbet liezen div vil schoenen kint ### des wart do von den gesten gevolget guotlichen sint
###### 555 | ### Der buhurt was zergangen vber allez daz velt ### do giengen kvrzwilen vnder manich hoch gecelt ### die riter zvo den vrowen vf hoher vroden wan ### da vertriben si die stvnde biz man riten wolde dan
###### 556 | ### Vor abende nahen do div svnne nider gie ### vnd ez begvnde kvoln niht lenger man daz lie ### sich huoben gen der burge manich man vn– wip ### mit ovgen wart getruotet vil maniger schoenen vrowen lip
###### 557 | ### Da wart von <gvten> knehten vil guoter kleider ab geriten ### von den hoch gemuoten nach des landes siten ### biz fur den palas da der kvnich nider stuont ### da wart gedient vrowen so helde hoch gemvote tuont
###### 558 | ### Do wurden ovch gescheiden die richen kvnigin ### frov vote vnd ir tohter die giengen beide hin ### mit ir ingesinde in ein vil witez gadem ### da horte man allenthalben ze frovden grozlichen schal
###### 559 | ### Gerichtet was gesidele der kvnich wolde gan ### ze tische mit den gesten do sach man bi im stan ### die schoenen Prvnhilde chrone si do trvoch ### in des kvniges lande ia was si rike genvoch
###### 560 | ### Des wirtes kæmerere von golde in peken rot ### daz wazzer fur truogen des wart luzel not ### ob iv daz ieman seite daz man diende baz [23b] ### ce fvrsten hochgezite ich wolde niht gelovben daz
###### 561 | ### E daz der voit von Rine wazzer da genam ### do tet der herre Sifrit als im daz gezam ### er mande in siner triwe wes er im verzach ### ê daz er Prunhilde da heime in Islande sach
###### 562 | ### Er sprach ir svlt gedenken wes mir swor iwer hant ### swenne daz vro Prvnhilt koeme in dize lant ### ir gebet mir iwer swester war sint die eide komen ### ich han an iwer reise vil michel arbeit genomen
###### 563 | ### Do sprach der kvnich ze dem gaste er habet mich rehte ermant ### ia sol niht meineide werden des min hant ### ich wilz iv helfen fuegen so ich beste kan ### do bat er Kriemhilde ce hove friuntlichen gan
###### 564 | ### Mit vil schoenen meiden si komen fvr den sal ### do spranch von einer stiegen Giselher zetal ### heizet wider keren disiv magedin ### min swester wan aleine sol hie bi dem kvnige sin
###### 565 | ### Do brahte man Kriemhilde da man den kvnich vant ### da stuonden riter edele von maniger fvrsten lant ### in dem sale witen man hiez si stille stan ### ovch was Prunhilt eben ze tische gegan
###### 566 | ### Do sprach der kvnich Gunther swester vil gemeit ### durch din selber tvgent losen minen eit ### ich swor dich eime reken wirdet er din man ### so hastv minen willen mit grozen triwen getan
###### 567 | ### Do sprach div meit edele lieber bruoder min ### ir svlt mich niht flegen ia wil ich immer sin ### swie ir mir gebietet daz sol sin getan ### ich wil in loben gerne swen ir mir herre gebet ze man
###### 568 | ### Von liebe vnd ovch von vrovden Sifrit wart rot ### ze dienste sich der reke vrovn Kriemhilde bot ### man bat si zvo an ander an dem ringe stan ### man vragte si ob si wolde den vil wetlichen man
###### 569 | ### In meitlichen zvhten si schamte sich ein teil ### doch so was geluke vnd Sifrides heil ### daz si in versprach alda niht zehant ### si lobte ovch ze wibe der edel kvnich von Niderlant
###### 570 | ### Do er si gelobete vnd ovch ir meit ### guotlichen vmbevahen was da vil bereit ### von Sifrides armen daz minneclichez chint ### vor helden wart gechusset div edel kvniginne sint
###### 571 | ### Sich teilte daz gesinde also daz geschach ### an daz gagensidel man Sifriden sach ### sicen mit Kriemhilde in diende manich man ### man sach die Niblunge mit Sifride gan
###### 572 | ### Der kvnich was gesezen vnd Prunhilt div meit ### do si sach Kriemhilde do wart ir nie so leit ### bi Sifride sicen weinen si began ### vber <liehtiv> wange sach man vallen trahen dan
###### 573 | ### Do sprach der wirt des landes waz ist iv frowe min [24a] ### daz ir so lazet <trveben> liehter ovgen schin ### ir svlt ivch vrovn balde iv ist vndertan ### min lant vnd min burge vnd manich wetlich man
###### 574 | ### Ich mach wol weinen balde sprach div schoene meit ### vmbe dine swester ist mir von herzen leit ### di sich ich sicen nahen dem eigen holden din ### daz muoz ich immer weinen sol si so verderbet sin
###### 575 | ### Do sprach der kvnich Gvnther ir svlt des stille dagen ### ich wil iv zanderen ziten disiv mere sagen ### warumbe ich miniv swester Sifride han gegeben ### ia mach si mit dem reken immer vroliche leben
###### 576 | ### Si sprach mich riwet immer ir schoene vnd ovch ir zuht ### wessich war ich mehte ich hete gerne fluht ### daz ich iv nimmer wolde geligen nahen bi ### irn saget mir wa von Chriemhilt wine Sifrides si
###### 577 | ### Do sprach der kvnich Gvnther ich tuon ez iv wol bechant ### er hat als ich wol burge vnde vnde lant ### daz wizzet sicherlichen er ist ein kvnich rich ### darumbe gab ich im ze wibe die schoenen meit lobelich
###### 578 | ### Swaz ir der kvnich seite doch hete si trovregen mvot ### do gahte von den tische manich riter guot ### ir buhurt wart so herte daz al div burch erdoz ### den wirt bi sinen gesten harte sere verdroz
###### 579 | ### Er dahte er lege sanfter der schoenen vrowen bi ### do was er des gedingen niht gar in herzen vri ### im mvose von ir schvlden liebe vil gesehen ### er begvnde frivntlichen an von Prunhilde sehen
###### 580 | ### Riterschaft der geste bat man abe lan ### der kvnich mit sime wibe ze bette wolde gan ### vor des sales stiegen gesamden sich do sit ### Kriemhilt vnd Prunhilt noch was ez beidenthalben ane nit
###### 581 | ### Do kom ir ingesinde die svmpten sich des niht ### ir riche kamerere die brahten in div lieht ### sich teilten do die reken der zweier kvnige man ### do sach man vil degene mit Sifriden gan
###### 582 | ### Die herren komen beide da si solden ligen ### do dahte ir ieweder mit min an gesigen ### den wetlichen vrovwen daz senftet in den mvot ### Sifrides kvrzwile div wart grozlichen guot
###### 583 | ### Ich sage iv niht mere wie er der vrowen pflach ### nv hoeret disiv mere wie Gvnther gelach ### bi frovwen Prvnhilde cierlicher degen ### er hete dike samfter bi anderen wiben gelegen
###### 584 | ### In saben wizen hemde si an daz bette gie ### do dahte der riter edele nu han ichz allez hie ### des ich ie da gerte in allen minen tagen ### si muos im durch ir schoene von grozen schvlden behagen
###### 585 | ### Div lieht begvnde bergen des edelen <kvniges> hant ### do gie der degen kuene da er die vrowen vant ### er leite sich ir nahen sin frovde div was groz [24b] ### die nu minneclichen der helt mit armen vmbesloz
###### 586 | ### Si sprach riter edel ir sultez lazen stan ### des ir da habet gedingen ia magez niht ergan ### ich wil noch meit beliben ir svlt wol merchen daz ### vnz ich div mere ervinde des wart ir Gvnther gehaz
###### 587 | ### Do rang er nach ir minne vnd zerfuorte ir div kleit ### do greif nach eime gvrtel div herliche meit ### eime starken borten dens vmb ir siten truoch ### do tet si dem kvnige grozer leide genvoch
###### 588 | ### Die fueze vnd ovch <die> hende si im zesamne bant ### si truog in zeime nagel vnd hiench in an ein want ### do er si slafes irte minne si ime verbot ### ia het er von ir krefte nach gewunnen den tot
###### 589 | ### Do begvnde flegen der meister solde sin ### loeset min gebende vil edel kvnigen ### ich trovwiv schoene vrovwe nimmer an gesigen ### vnd sol ovch harte selten iv so nahen bi geligen
###### 590 | ### Nv saget mir er Gvnther ist iv daz iht leit ### ob ivch gebvnden vindent sprach schoene meit ### iwere kamerere von einer vrowen hant ### do sprach der riter edele daz wurde iv vbel bewant
###### 591 | ### ovch het ichs wenich ere sprach der edel man ### dvrch iwer tvgende lat zvo ziv mich nv gan ### sit iv mine minne sint so starke leit ### ich sol mit minen handen selten rueren <iwer> kleit
###### 592 | ### Do loste <si> in balde vf si in verlie ### wider an daz bette er zvo der vrowen gie ### er leite sich so verre daz er ir schoene wat ### darnach selten ruorte ovch wolde si des haben rat
###### 593 | ### Do kom ovch ir gesinde die brahten niwe kleit ### der was in an den morgen harte vil bereit ### swie wol man da gebarte truorich was sin mvot ### der herre des landes ir frovde duht in niht ze gvot
###### 594 | ### Nach siten der si pflagen vnd man dvrch reht begie ### Gvnther vnde Prunhilt niht langer daz verlie ### si giengen zvo dem mvnster da man die messe sanch ### dar kom ovch er Sifrit do hvop sich michel gedranc
###### 595 | ### Nach kvniklichen eren was in dar bereit ### swaz si haben solden ir krone vnd ovch ir kleit ### do wurden si gewihet do daz was getan ### do sach man vnder krone elliv fieriv schoene stan
###### 596 | ### Vil degen swert da namen sehs hundert oder baz ### den kvnigen ze eren ir svlt wizzen daz ### sich huop michel freude in Bvrgonden lant ### man horte schefte hellen an der swertdegen hant
###### 597 | ### Do sazzen in den venstren div schoenen meidin ### si sahen vor ir luhten maniges schildes schin ### do hete sich gesvndert der chvnich von sinen man ### swes ieman da begvnde man sach in trovrinde gan
###### 598 | ### Im vnd Sifride vngelich stuont der muot [25a] ### wol wiste waz im wurre der riter edel guot ### er gie zuo dem kvnige vragen er began ### wie ist iv heint gelvngen daz sult ir mich wizen lan
###### 599 | ### Do sprach der wirt zem gaste laster vnde schaden ### han ich an miner vrovwen ze hvse heim geladen ### do ich se wande minnen vil sere si mich bant ### si truoch mich zeime nagele vnd hiench mich hoh an eine want
###### 600 | ### Da hieng ich angestlichen die naht vnz an den tac ### ê si mich enbvnde wie samphte si do lac ### daz sol dir frivntlichen tovgen sin gechleit ### do sprach der starke Sifrit daz ist mir werlichen leit
###### 601 | ### Des bring ich iv wol innen lat irz ane nit ### ich schaffe daz si hinaht so nahen bi iv lit ### daz si ivch ir minne gesuomet nimmer mer ### der rede was do Gvnther nach sinen arbeiten her
###### 602 | ### Er sprach ich kvme noch heint ze der kemenaten sin ### also tovgenliche in der tarnkappe min ### daz sich der liste mach nieman wol versten ### so lat die kamerere zuo den herbergen <gen>
###### 603 | ### So lesche ich den kinden div lieht an der hant ### daz ich si darinne si iv dabi bechant ### daz ich iv gerne diene ich twing iv daz wip ### daz ir si heint minnet oder ich verlivse den lip
###### 604 | ### An daz dv iht trovtest sprach der kvnich do ### mine lieben vrowen anders bin vro ### so tuo ir swaz dv wellest vnde nemest ir den lip ### daz sold ich wol derkiesen si ist ein angestlichez wip
###### 605 | ### Daz tuon ich sprach Syfrit vf die triwe min ### daz ich ir niht minne div liebe swester din ### ist mir vor in allen die ich noch ie gesach ### vil wol gelovbetez Gvnther swaz do Sifrit gesprach
###### 606 | ### Da was von kurzewile vrovde vnde not ### buhurt vnde schallen man allez verbot ### da die vrowen solden gegen dem sale gan ### do hiezen kamerere die lûte von den wegen stan
###### 607 | ### Von rossen vnd von lûten gerumet wart der hof ### der vrowen isliche fuorte ein bischof ### do si vor dem kvnigen ze tische solden gan ### in volgete an daz gesidele vil maniger wetlicher man
###### 608 | ### Der kvnich beite kvme daz man von tische gie ### die schoenen Prvnhilde man do komen lie ### vnd ovch Chriemhilde beide an ir gemach ### hei waz man sneller degne vor den kvniginnen sach
###### 609 | ### Sifrit der herre vil minneclichen saz ### bi sime schoenen wibe mit vrovden an haz ### si trvote sine hende mit ir vil wizen hant ### vnz er vor ir ovgen si ne wesse wenne verswant
###### 610 | ### Do si mit im spilte vnd si si niht ensach ### zvo sime ingesinde div kvniginne sprach ### mich hat des michel wunder war ist der kvnich komen [25b] ### wer hat di sinen hende vz den minen genomen
###### 611 | ### Die rede si lie beliben er was hin gegan ### da er die kamerere vant mit liehtem stan ### div begvnde er leschen den kinden an der hant ### daz ez were Syfrit daz wart do Gvnther bechant
###### 612 | ### Wol wesse er waz er wolde do hiez er dannen gan ### meide vnde vrovwen do daz was getan ### der edel kvnich do selbe vil wol besloz div tûre ### starker rigele zwene warf er balde derfvre
###### 613 | ### Div lieht verbar er schiere vnder die bete wat ### eins spils begvnde des enwas niht rat ### Sifrit der starke vnd ovch div schoene meit ### das was dem kvnige Gvnther beide lieb vnde leit
###### 614 | ### Sifrit sich leite do der kvniginne bi ### si sprach nv latez er Gvnther alse liep iv daz si ### daz ir iht arebeite lidet alsam ê ### oder iv geschihet von minen handen we
###### 615 | ### Do hal er sine stimme daz er niht sprach ### Gvnther wol horte swie er niht ensach ### daz heimliche von in da niht geschach ### si heten an dem bette harte cleinen gemach
###### 616 | ### Er gebarte sam ez were der chvnich Gvnther rich ### er vmbesloz mit armen die maget lobelich ### si warf in vz den bette da bi vf eine banc ### daz si im sin hovbet lûte an eime schamel erclanch
###### 617 | ### Wider vf mit kreften spranch der kuene man ### er woldez baz versuochen do er des began ### daz er si wolde twingen darvmbe wart im we ### solich wer an frovwen ich wene nimmer erge
###### 618 | ### Do er niht wolde erwinden div maget vf spranch ### iv cimet mich niht zefuoren min hemde so blanch ### ir sit vngefuege daz sol ivch werden leit ### des bringe ich iv wol innen sprach div wetliche meit
###### 619 | ### Si besloz mit armen den tiwerlichen degen ### vnd wold in gebvnden alsam den kvnich legen ### daz si an dem bette hete gvt gemach ### daz er ir wat zerfuorte div vrovwe ez grozlichen rach
###### 620 | ### Waz half do sin sterke vnd ovch sin kraft ### wan si im erzeigete ir libes meisterschaft ### si truoch in mit gewalte daz muoz et also sin ### vnd druchte in vngefvege bi dem bette an einen schrin
###### 621 | ### Owe gedaht der reke sol ich minen lip ### von einer meit verliesen so mvgen elliv wip ### darnach immer mere tragen gelphen mvot ### gen ir manne div sus ez nimmer getuot
###### 622 | ### Der kvnich er wol horte er angeste vmbe den man ### Syfrit sich schamte zvrnen er began ### mit vngefuegen krefte satzter er sic wider ### versuohende angestlichen an fron Prvnhilde sider
###### 623 | ### Den kvnich dûhte lange ê er si betwanch [26a] ### si druhte sine hende daz uz den naglen spranch ### daz bluot von ir krefte daz was den helde leit ### des braht er an lovgen sit die herlichen meit
###### 624 | ### ir vngefueges willen des si ê da iach ### der kvnich ez allez horte swie er niht ensprach ### er druhtes an daz bette daz ez vil lûte erschre ### ir taten sine krefte harte grozlichen we
###### 625 | ### Do greif si zuo der siten da si den porten vant ### vnd wold in han gebvnden do wertez so sin hant ### daz ir div lit erkrachten dar zvo al der lip ### des wart der kriech gescheiden do wart si Gvnthers wip
###### 626 | ### Si sprach kvnich edel du solt mich leben lan ### ez wirt wol versvenet swaz ich dir han getan ### ich were <mich> nimmer me der edelen minne din ### ich han wol erfvnden daz dv kanst vrovwen meister sin
###### 627 | ### Sifrit der stuont dannen ligen lie er die meit ### sam ob er von im ziehen wolde siniv kleit ### er zoch ir ab der hende ein gvlden vingerlin ### daz da nie wart innen div edel kvnigin
###### 628 | ### Dar zuo nam er ir gurtel daz was ein borte guot ### ich en weiz ob er daz tete durch sinen hohen mvot ### er gap in sinen wibe daz wart im sider leit ### do lagen bi an ander der kvnich vnd div schoene meit
###### 629 | ### Do was ovch si niht sterker danne an ander wip ### er trvte minneclichen ir vil schoenen lip ### ob siz versuohte me waz kvnd ez si veruan ### daz het ir allez Gvnther mit sinen minnen getan
###### 630 | ### Wie rehte minnecliche er bi der vrowen lach ### mit vrivntlicher liebe biz an den liehten tach ### nv was der herre Sifrit wider vz gegan ### da er wol enphangen von einer vrowen wolgetan
###### 631 | ### Er vnderstuont ir vrage der si hete getan ### er hal si sit vil lange daz er ir hete braht ### vnz si vnder krone in sime lande gie ### swaz er ir geben solde wie luzel er ez beliben lie
###### 632 | ### Der wirt wart an dem morgen verre baz gemuot ### danner vore were des wart div frovde guot ### in allen den landen von manigen edel man ### die er ze hvse ladete den wart vil dienst getan
###### 633 | ### Div hochcit div werte den vierzehenden tac ### daz in al der wile nie der schal gelach ### von aller hande vrovden der ieman solde pflegen ### da wart des kvniges koste vil harte hohe gewegen
###### 634 | ### Des edelen wirtes mage als ez der kvnich gebot ### gaben durch sin ere kleider vnde golt rot ### ros vnde darzvo silber manigen kuenen man ### die herren die dar komen schieden frolichen dan
###### 635 | ### Vnd der kvnich Sifrit vzer Niderlant ### mit tusent sinen mannen allez ir gewant ### daz si dar brahten daz wart gar hin gegeben [26b] ### schoeniv ros mit setelen si kvnden herlichen leben
###### 636 | ### E daz man die rike gabe da verswanch ### die da wolden ce lande duhte des ce lanch ### ez wart nie gesindes mere baz geflegen ### so endete sich div hochcit ez sciet von dannen manic degen

<<< Übersicht <<< vorige Seite nächste Seite >>>